"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseAgileService = void 0;
const constants_1 = require("../../constants");
const utils_1 = require("../../utils");
class BaseAgileService {
    constructor(config) {
        this.config = config;
    }
    // Base functions
    createSprints(sprints) {
        return __awaiter(this, void 0, void 0, function* () {
            sprints = sprints || this.generateSprints();
            return this.confirmAndCreateSprints(sprints);
        });
    }
    // Private functions
    generateSprints() {
        const { sprints: sprintConfig } = this.config;
        if (!sprintConfig) {
            throw new Error("Section agile.sprints of projector.json is required for this operation");
        }
        const { startDate, lengthOfSprintInDays, numberOfSprints, daysBetweenSprints, sprintNamePattern, sprintIndexStart, } = sprintConfig;
        const namePattern = sprintNamePattern || utils_1.Config.getValue(constants_1.ConfigValue.DefaultSprintNamePattern);
        const indexStart = sprintIndexStart || utils_1.Config.getValue(constants_1.ConfigValue.DefaultSprintStartIndex);
        const sprints = [];
        const timezoneOffset = new Date().getTimezoneOffset() * constants_1.NumberConstants.millisecondsInAMinute;
        let currentStartDate = new Date(Date.parse(startDate) + timezoneOffset);
        for (let i = indexStart; i <= numberOfSprints; i++) {
            const finishDate = utils_1.DateUtils.addDays(currentStartDate, lengthOfSprintInDays - 1);
            sprints.push({
                name: namePattern.replace("${sprintIndex}", i.toString()),
                startDate: currentStartDate,
                finishDate,
            });
            currentStartDate = utils_1.DateUtils.addDays(finishDate, daysBetweenSprints + 1);
        }
        return sprints;
    }
    confirmAndCreateSprints(sprints) {
        return __awaiter(this, void 0, void 0, function* () {
            utils_1.Logger.log("The following sprints will be created:\n");
            sprints.forEach((sprint) => {
                const { name, startDate, finishDate } = sprint;
                utils_1.Logger.log(`${name}:\t${utils_1.DateUtils.toSimpleDateString(startDate)}\t${utils_1.DateUtils.toSimpleDateString(finishDate)}`);
            });
            if (yield utils_1.UserUtils.confirmAction()) {
                utils_1.Logger.log("\nCreating sprints...");
                const createdSprints = yield this.createProviderSprints(sprints);
                utils_1.Logger.log("\nCreated sprints");
                return createdSprints;
            }
            else {
                utils_1.Logger.log("Operation cancelled");
                return [];
            }
        });
    }
}
exports.BaseAgileService = BaseAgileService;
