"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfigService = void 0;
const constants_1 = require("../../constants");
const utils_1 = require("../../utils");
const agile_1 = require("../agile");
/**
 * Class dealing with the Projector configuration.
 */
class ConfigService {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars, @typescript-eslint/explicit-module-boundary-types
    static createInitialConfig(options) {
        const { agileProvider } = options;
        return {
            agile: agileProvider ? this.createAgileConfig(agileProvider) : undefined,
            github: this.createGithubConfig(),
        };
    }
    static getExistingConfig(options) {
        const githubToken = options === null || options === void 0 ? void 0 : options.githubToken;
        const configFile = options === null || options === void 0 ? void 0 : options.configFile;
        const config = utils_1.FileUtils.readJson(configFile || constants_1.FileConstants.configFileName);
        if (!githubToken) {
            return config ? config : {};
        }
        if (!config) {
            return {
                github: {
                    personalAccessToken: githubToken,
                },
            };
        }
        return Object.assign(Object.assign({}, config), { github: Object.assign(Object.assign({}, config.github), { personalAccessToken: githubToken }) });
    }
    static createAgileConfig(provider) {
        const now = new Date();
        return {
            providerName: provider,
            providerOptions: this.getProviderOptions(provider),
            sprints: {
                startDate: `${now.getFullYear()}-${now.getMonth() + 1}-${now.getDate()}`,
                lengthOfSprintInDays: utils_1.Config.getValue(constants_1.ConfigValue.DefaultSprintLength),
                daysBetweenSprints: utils_1.Config.getValue(constants_1.ConfigValue.DefaultDaysBetweenSprints),
                numberOfSprints: utils_1.Config.getValue(constants_1.ConfigValue.DefaultNumberOfSprints),
                sprintIndexStart: utils_1.Config.getValue(constants_1.ConfigValue.DefaultSprintStartIndex),
                sprintNamePattern: utils_1.Config.getValue(constants_1.ConfigValue.DefaultSprintNamePattern),
            },
        };
    }
    static createGithubConfig() {
        return {
            personalAccessToken: "{Not required, but allows for greater API limit when reading from GitHub repos}",
        };
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    static getProviderOptions(provider) {
        switch (provider) {
            case agile_1.AgileServiceProvider.AzureDevOps:
            default:
                const azDoProviderOptions = {
                    baseUrl: "{Base URL for Azure DevOps organization}",
                    projectName: "{Name of Azure DevOps project}",
                    personalAccessToken: "{Go to 'https://dev.azure.com/{organization}/_usersSettings/tokens' to generate token}",
                };
                return azDoProviderOptions;
        }
    }
}
exports.ConfigService = ConfigService;
