"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CsePlaybookService = void 0;
const constants_1 = require("../../constants");
const samples_1 = require("../../samples");
const utils_1 = require("../../utils");
class CsePlaybookService {
    constructor(repoService) {
        this.repoService = repoService;
        this.playbookOwnerName = utils_1.Config.getValue(constants_1.ConfigValue.PlaybookOwnerName);
        this.playbookRepoName = utils_1.Config.getValue(constants_1.ConfigValue.PlaybookRepoName);
    }
    getTemplates() {
        return __awaiter(this, void 0, void 0, function* () {
            // Stub for now until we fetch templates from the repo
            return Promise.resolve([samples_1.exampleBacklogItemTemplate, samples_1.emptyBacklogItemTemplate]);
        });
    }
    getRepoItem(pathInRepo, includeContent = false) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.repoService.getRepoItem(this.playbookOwnerName, this.playbookRepoName, pathInRepo, includeContent);
        });
    }
    downloadRepoItem(pathInRepo, localRelativePath) {
        return __awaiter(this, void 0, void 0, function* () {
            const { content } = yield this.getRepoItem(pathInRepo, true);
            if (!content) {
                throw new Error(`Couldn't get content from repo path ${pathInRepo}`);
            }
            utils_1.FileUtils.writeFile(localRelativePath, content);
        });
    }
}
exports.CsePlaybookService = CsePlaybookService;
