"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseRepoService = void 0;
const path_1 = require("path");
const models_1 = require("../../models");
const utils_1 = require("../../utils");
class BaseRepoService {
    // Base functions
    downloadRepoItem(owner, repo, path, branch, outputPath = process.cwd()) {
        return __awaiter(this, void 0, void 0, function* () {
            const repoItem = yield this.getRepoItem(owner, repo, path, true, branch);
            yield this.writeRepoItem(repoItem, outputPath);
        });
    }
    listRepoItems(owner, repo, path = "", branch) {
        return __awaiter(this, void 0, void 0, function* () {
            const repoItem = yield this.getRepoItem(owner, repo, path, false, branch);
            const { type, children } = repoItem;
            return type === models_1.RepoItemType.Directory && children ? children : [];
        });
    }
    // Private functions
    writeRepoItem(repoItem, outputPath) {
        return __awaiter(this, void 0, void 0, function* () {
            const { content, children, name, type } = repoItem;
            yield utils_1.FileUtils.mkdirIfNotExists(outputPath);
            const repoItemPath = path_1.join(outputPath, name);
            if (type === models_1.RepoItemType.Directory) {
                yield utils_1.FileUtils.mkdirIfNotExists(repoItemPath);
                if (children) {
                    yield Promise.all(children.map((item) => this.writeRepoItem(item, repoItemPath)));
                }
            }
            else if (content) {
                yield utils_1.FileUtils.writeFile(repoItemPath, content);
            }
        });
    }
}
exports.BaseRepoService = BaseRepoService;
