"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitHubRepoService = void 0;
const rest_1 = require("@octokit/rest");
const axios_1 = __importDefault(require("axios"));
const path_1 = require("path");
const constants_1 = require("../../../constants");
const models_1 = require("../../../models");
const utils_1 = require("../../../utils");
const baseRepoService_1 = require("../baseRepoService");
class GitHubRepoService extends baseRepoService_1.BaseRepoService {
    constructor(config) {
        super();
        this.getRepoItem = (owner, repo, path = "", includeContent, branch) => __awaiter(this, void 0, void 0, function* () {
            try {
                const { data } = yield this.github.repos.getContent({
                    owner,
                    repo,
                    path,
                    ref: branch,
                });
                if (data instanceof Array) {
                    const children = yield Promise.all(
                    // eslint-disable-next-line @typescript-eslint/no-explicit-any
                    data.map((item) => __awaiter(this, void 0, void 0, function* () {
                        return yield this.getRepoItem(owner, repo, item.path, includeContent);
                    })));
                    return {
                        name: path_1.basename(path),
                        type: models_1.RepoItemType.Directory,
                        path,
                        children,
                    };
                }
                else {
                    // eslint-disable-next-line @typescript-eslint/no-explicit-any
                    const { download_url } = data;
                    return {
                        name: path_1.basename(path),
                        type: models_1.RepoItemType.File,
                        path,
                        content: includeContent ? (yield axios_1.default.get(download_url)).data : undefined,
                    };
                }
            }
            catch (err) {
                const { status } = err;
                if (status && status === 403) {
                    const message = "API rate limit exceeded. Try setting GITHUB_TOKEN in your local .env file with a token from GitHub";
                    throw new Error(message);
                }
                else {
                    throw new Error(`Ran into problem getting items from GitHub: \n\n${JSON.stringify(err, null, 2)}`);
                }
            }
        });
        this.latestCommit = (owner, repo, branch) => __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.github.repos.getCommit({
                owner,
                repo,
                ref: branch,
            });
            const { sha } = data;
            if (!sha) {
                throw new Error(`Could not find latest commit for ${owner}/${repo}`);
            }
            return sha;
        });
        // Prefer environment variable over config
        const accessToken = utils_1.Config.getValueWithDefault(constants_1.ConfigValue.GithubAccessToken, config === null || config === void 0 ? void 0 : config.personalAccessToken);
        this.github = new rest_1.Octokit({
            userAgent: "projector",
            auth: accessToken,
        });
    }
}
exports.GitHubRepoService = GitHubRepoService;
